import React from "react";
import "./sidepanel.css";

import HistoryNavigator from "./historynavigator";
import { DynamicGraph } from "../graph";
import NodeDetails from "./nodedetails";
import { NodeTypesEditor } from "./nodetypeseditor";
import Settings from "./settings";
import Instructions from "./instructions";
import { Checkpoint } from "../../common/history";
import { Node } from "../../common/graph/node";
import { NodeType } from "../../common/graph/nodetype";
import { SimGraphData } from "../../common/graph/graph";
import { EditorSettings, NodeDataChangeRequest } from "../editor";

interface SidepanelProps {
    graph: DynamicGraph;
    onCheckpointLoad: { (checkpoint: Checkpoint<SimGraphData>): void };
    onNodeTypeSelect: (type: NodeType) => void;
    onSettingsChange: (settings: EditorSettings) => void;
    onNodeDataChange: { (requests: NodeDataChangeRequest[]): void };
    selectedNodes: Node[];
    settings: EditorSettings;
}

function Sidepanel({
    graph,
    onCheckpointLoad,
    onNodeTypeSelect,
    onSettingsChange,
    onNodeDataChange,
    selectedNodes,
    settings,
}: SidepanelProps) {
    return (
        <div className={"editor-sidepanel"}>
            <HistoryNavigator
                history={graph.history}
                onCheckpointLoad={onCheckpointLoad}
            />
            <hr />
            <NodeDetails
                selectedNodes={selectedNodes}
                idToObjectType={graph.idToObjectGroup}
                onNodeDataChange={onNodeDataChange}
            />
            <hr />
            <NodeTypesEditor
                onChange={() =>
                    console.log("Refactor onChange for nodetypes editor!")
                } // TODO: Refactor
                graph={graph}
                onSelectAll={onNodeTypeSelect}
            />
            <hr />
            <Settings settings={settings} onSettingsChange={onSettingsChange} />
            <hr />

            <Instructions connectOnDragEnabled={settings.connectOnDrag} />
        </div>
    );
}

export default Sidepanel;
